public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH 2.6.13-rc6-mm2] ppp_mppe: author email change
@ 2005-08-30  3:18 Matt Domsch
  0 siblings, 0 replies; only message in thread
From: Matt Domsch @ 2005-08-30  3:18 UTC (permalink / raw)
  To: akpm; +Cc: fcusack, linux-kernel, pptpclient-devel

Frank Cusack, primary author of the ppp_mppe kernel module, is no
longer at Google.  This updates his email address in the module, as
agreed to by Frank privately.

 ppp_mppe.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

Signed-off-by: Matt Domsch <Matt_Domsch@dell.com>

-- 
Matt Domsch
Software Architect
Dell Linux Solutions linux.dell.com & www.dell.com/linux
Linux on Dell mailing lists @ http://lists.us.dell.com

diff -urNp --exclude-from=/home/mdomsch/excludes --minimal linux-2.6.13-rc6-mm2.orig/drivers/net/ppp_mppe.c linux-2.6.13-rc6-mm2/drivers/net/ppp_mppe.c
--- linux-2.6.13-rc6-mm2.orig/drivers/net/ppp_mppe.c	Mon Aug 29 22:08:58 2005
+++ linux-2.6.13-rc6-mm2/drivers/net/ppp_mppe.c	Mon Aug 29 22:10:23 2005
@@ -2,7 +2,7 @@
  * ppp_mppe.c - interface MPPE to the PPP code.
  * This version is for use with Linux kernel 2.6.14+
  *
  * By Frank Cusack <frank@google.com>.
  * Copyright (c) 2002,2003,2004 Google, Inc.
  * All rights reserved.
  *
@@ -59,7 +59,7 @@
 
 #include "ppp_mppe.h"
 
-MODULE_AUTHOR("Frank Cusack <frank@google.com>");
+MODULE_AUTHOR("Frank Cusack <fcusack@fcusack.com>");
 MODULE_DESCRIPTION("Point-to-Point Protocol Microsoft Point-to-Point Encryption support");
 MODULE_LICENSE("Dual BSD/GPL");
 MODULE_ALIAS("ppp-compress-" __stringify(CI_MPPE));

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2005-08-30  3:18 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -2,7 +2,7 @@
  * This version is for use with Linux kernel 2.6.14+
  *
- * By Frank Cusack <frank@google.com>.
+ * By Frank Cusack <fcusack@fcusack.com>.
  * Copyright (c) 2002,2003,2004 Google, Inc.
  * All rights reserved.
2005-08-30  3:18 [PATCH 2.6.13-rc6-mm2] ppp_mppe: author email change Matt Domsch

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox